==> haskell-missingh-1.4.0.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.0.1
id: MissingH-1.4.0.1-DLm2Rkpjei1WszFJT4i7T
key: MissingH-1.4.0.1-DLm2Rkpjei1WszFJT4i7T
license: BSD3
copyright: Copyright (c) 2004-2016 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
author: John Goerzen
exposed: True
exposed-modules:
    Data.String.Utils System.IO.Utils System.IO.Binary Data.List.Utils
    System.Daemon Text.ParserCombinators.Parsec.Utils
    Network.Email.Mailbox Control.Concurrent.Thread.Utils
    Network.Email.Sendmail Data.CSV System.Cmd.Utils Data.BinPacking
    Data.Progress.Tracker Data.Progress.Meter Data.Quantity
    Data.Map.Utils System.Path System.Path.NameManip
    System.Path.WildMatch System.Path.Glob System.Time.Utils
    Network.Utils Network.SocketServer Data.Either.Utils
    Data.Maybe.Utils Data.Tuple.Utils Data.Bits.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.Compression.Inflate System.FileArchive.GZip System.IO.HVFS
    System.IO.HVFS.Combinators System.IO.HVFS.InstanceHelpers
    System.IO.HVFS.Utils System.IO.HVIO System.IO.StatCompat
    System.IO.WindowsCompat System.IO.PlafCompat System.Posix.Consts
    System.Debian System.Debian.ControlParser Data.MIME.Types
    System.Console.GetOpt.Utils
abi: b00f7bea4f96fb334ba75d181feb8482
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/MissingH-1.4.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/MissingH-1.4.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/MissingH-1.4.0.1
hs-libraries: HSMissingH-1.4.0.1-DLm2Rkpjei1WszFJT4i7T
depends:
    HUnit-1.5.0.0-CCvWASKpeWzFD7O0KoAt2G array-0.5.1.1 base-4.9.0.0
    containers-0.5.7.1 directory-1.2.6.2 filepath-1.4.1.0
    hslogger-1.2.10-6Ih3VN3QBbAJ6pLH6h3KNu
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-compat-0.95.1-JPDhOGKcrkD8S1t3VsLLUt time-1.6.0.1
    unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.4.0.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.0.1
id: MissingH-1.4.0.1-6RrE79GWNvb69bc6aao4Yr
key: MissingH-1.4.0.1-6RrE79GWNvb69bc6aao4Yr
license: BSD3
copyright: Copyright (c) 2004-2016 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
author: John Goerzen
exposed: True
exposed-modules:
    Data.String.Utils System.IO.Utils System.IO.Binary Data.List.Utils
    System.Daemon Text.ParserCombinators.Parsec.Utils
    Network.Email.Mailbox Control.Concurrent.Thread.Utils
    Network.Email.Sendmail Data.CSV System.Cmd.Utils Data.BinPacking
    Data.Progress.Tracker Data.Progress.Meter Data.Quantity
    Data.Map.Utils System.Path System.Path.NameManip
    System.Path.WildMatch System.Path.Glob System.Time.Utils
    Network.Utils Network.SocketServer Data.Either.Utils
    Data.Maybe.Utils Data.Tuple.Utils Data.Bits.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.Compression.Inflate System.FileArchive.GZip System.IO.HVFS
    System.IO.HVFS.Combinators System.IO.HVFS.InstanceHelpers
    System.IO.HVFS.Utils System.IO.HVIO System.IO.StatCompat
    System.IO.WindowsCompat System.IO.PlafCompat System.Posix.Consts
    System.Debian System.Debian.ControlParser Data.MIME.Types
    System.Console.GetOpt.Utils
abi: 4b77f4e94ffffd790b16e248907866d7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/MissingH-1.4.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/MissingH-1.4.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/MissingH-1.4.0.1
hs-libraries: HSMissingH-1.4.0.1-6RrE79GWNvb69bc6aao4Yr
depends:
    HUnit-1.6.0.0-FzD79SWxsfL7BH2Ung8YXe array-0.5.1.1 base-4.9.0.0
    containers-0.5.7.1 directory-1.2.6.2 filepath-1.4.1.0
    hslogger-1.2.10-6Ih3VN3QBbAJ6pLH6h3KNu
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-compat-0.95.1-JPDhOGKcrkD8S1t3VsLLUt time-1.6.0.1
    unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
